@@ -132,3 +132,26 @@ def test_bulk_locks_gives_exc_after_few_iterations_check_acquired_locks_are_reve
     with pytest.raises(RuntimeError):
         assert not client.acquire_locks(keys, "dummy_session")
         assert fake_release.called
+
+
+@patch("consul_sdk.client.ConsulClient._acquire_locks")
+@patch("consul_sdk.client.ConsulClient.release_locks")
+def test_bulk_locks_unable_to_acquire_lock_after_few_iterations_check_acquired_locks_are_reverted_unit_test(
+    fake_release, fake__acquire_locks, client
+):
+    keys = [f"my-key-{i}" for i in range(70)]
+    fake__acquire_locks.side_effect = [True, False]
+
+    assert not client.acquire_locks(keys, "dummy_session")
+    assert fake_release.called
+
+
+@pytest.mark.integration
+def test_bulk_lock_for_single_key(client):
+    session_id_1 = client.create_session(10)
+    session_id_2 = client.create_session(10)
+    key = "dummy_fleet:dummy_vehicle_allocation/dummy_vehicle_id/4d7e8ac0-b95b-427a-0000-00fd8ce00000"
+
+    assert client.acquire_locks([key], session_id_1)
+    assert not client.acquire_locks([key], session_id_2)
+    assert client.release_locks([key], session_id_1)
